@@ -1,7 +1,7 @@
 <?php
 
 $lang['friendlyname'] = "Evènements et manifestations";
-$lang['admindescription'] = "Module de gestion d'un calendrier d'événements, avec possibilité pour les visiteurs du site de s'inscrire.";
+$lang['admindescription'] = "Module de gestion d'un calendrier d'&eacute;v&eacute;nements, avec possibilit&eacute; pour les visiteurs du site de s'inscrire via FrontEndUsers";
 
 $lang['postinstall'] = "Le module EventsManager (calendrier d'événements) a bien été installé - Vous pouvez l'utiliser via le menu \"Contenu\". N'oubliez pas de donner les droits liés à \"EventsManager\" à vos admins/rédacteurs/designers.";
 $lang['preuninstall'] = 'Êtes-vous sûr de vouloir supprimer le module ainsi que tous vos événements ?';
